@@ -190,7 +190,7 @@ class EnvManager(object):
         try:
             python_version = decode(
                 subprocess.check_output(
-                    " ".join(
+                    list_to_shell_command(
                         [
                             python,
                             "-c",
@@ -427,7 +427,7 @@ class EnvManager(object):
         try:
             python_version = decode(
                 subprocess.check_output(
-                    " ".join(
+                    list_to_shell_command(
                         [
                             python,
                             "-c",
@@ -473,6 +473,10 @@ class EnvManager(object):
 
         cwd = self._poetry.file.parent
         env = self.get(reload=True)
+
+        if not env.is_sane():
+            force = True
+
         if env.is_venv() and not force:
             # Already inside a virtualenv.
             return env
@@ -494,18 +498,19 @@ class EnvManager(object):
         python_patch = ".".join([str(v) for v in sys.version_info[:3]])
         python_minor = ".".join([str(v) for v in sys.version_info[:2]])
         if executable:
-            python_minor = decode(
+            python_patch = decode(
                 subprocess.check_output(
-                    " ".join(
+                    list_to_shell_command(
                         [
                             executable,
                             "-c",
-                            "\"import sys; print('.'.join([str(s) for s in sys.version_info[:2]]))\"",
+                            "\"import sys; print('.'.join([str(s) for s in sys.version_info[:3]]))\"",
                         ]
                     ),
                     shell=True,
                 ).strip()
             )
+            python_minor = ".".join(python_patch.split(".")[:2])
 
         supported_python = self._poetry.package.python_constraint
         if not supported_python.allows(Version.parse(python_patch)):
@@ -517,7 +522,7 @@ class EnvManager(object):
             # Otherwise, we try to find a compatible Python version.
             if executable:
                 raise NoCompatiblePythonVersionFound(
-                    self._poetry.package.python_versions, python_minor
+                    self._poetry.package.python_versions, python_patch
                 )
 
             io.write_line(
@@ -552,7 +557,7 @@ class EnvManager(object):
                 try:
                     python_patch = decode(
                         subprocess.check_output(
-                            " ".join(
+                            list_to_shell_command(
                                 [
                                     python,
                                     "-c",
@@ -605,6 +610,12 @@ class EnvManager(object):
             self.build_venv(str(venv), executable=executable)
         else:
             if force:
+                if not env.is_sane():
+                    io.write_line(
+                        "<warning>The virtual environment found in {} seems to be broken.</warning>".format(
+                            env.path
+                        )
+                    )
                 io.write_line(
                     "Recreating virtualenv <c1>{}</> in {}".format(name, str(venv))
                 )
@@ -637,7 +648,9 @@ class EnvManager(object):
             # Create virtualenv by using an external executable
             try:
                 p = subprocess.Popen(
-                    " ".join([executable, "-"]), stdin=subprocess.PIPE, shell=True
+                    list_to_shell_command([executable, "-"]),
+                    stdin=subprocess.PIPE,
+                    shell=True,
                 )
                 p.communicate(encode(CREATE_VENV_COMMAND.format(path)))
             except CalledProcessError as e:
@@ -702,6 +715,7 @@ class Env(object):
 
         self._marker_env = None
         self._pip_version = None
+        self._site_packages = None
 
     @property
     def path(self):  # type: () -> Path
@@ -757,20 +771,25 @@ class Env(object):
 
     @property
     def site_packages(self):  # type: () -> Path
-        # It seems that PyPy3 virtual environments
-        # have their site-packages directory at the root
-        if self._path.joinpath("site-packages").exists():
-            return self._path.joinpath("site-packages")
+        if self._site_packages is None:
+            site_packages = []
+            dist_packages = []
+            for entry in self.sys_path:
+                entry = Path(entry)
+                if entry.name == "site-packages":
+                    site_packages.append(entry)
+                elif entry.name == "dist-packages":
+                    dist_packages.append(entry)
 
-        if self._is_windows:
-            return self._path / "Lib" / "site-packages"
+            if not site_packages and not dist_packages:
+                raise RuntimeError("Unable to find the site-packages directory")
 
-        return (
-            self._path
-            / "lib"
-            / "python{}.{}".format(*self.version_info[:2])
-            / "site-packages"
-        )
+            if site_packages:
+                self._site_packages = site_packages[0]
+            else:
+                self._site_packages = dist_packages[0]
+
+        return self._site_packages
 
     @property
     def sys_path(self):  # type: () -> List[str]
@@ -1113,6 +1132,7 @@ class MockEnv(NullEnv):
         os_name="posix",
         is_venv=False,
         pip_version="19.1",
+        sys_path=None,
         **kwargs
     ):
         super(MockEnv, self).__init__(**kwargs)
@@ -1123,6 +1143,7 @@ class MockEnv(NullEnv):
         self._os_name = os_name
         self._is_venv = is_venv
         self._pip_version = Version.parse(pip_version)
+        self._sys_path = sys_path
 
     @property
     def version_info(self):  # type: () -> Tuple[int]
@@ -1144,5 +1165,12 @@ class MockEnv(NullEnv):
     def pip_version(self):
         return self._pip_version
 
+    @property
+    def sys_path(self):
+        if self._sys_path is None:
+            return super(MockEnv, self).sys_path
+
+        return self._sys_path
+
     def is_venv(self):  # type: () -> bool
         return self._is_venv
