@@ -181,10 +181,11 @@ class SetupReader(object):
                 continue
 
             func = value.func
-            if not isinstance(func, ast.Name):
-                continue
-
-            if func.id != "setup":
+            if not (isinstance(func, ast.Name) and func.id == "setup") and not (
+                isinstance(func, ast.Attribute)
+                and func.value.id == "setuptools"
+                and func.attr == "setup"
+            ):
                 continue
 
             return value, elements
